@@ -1,2 +1,2 @@
 from discordwebhook import create, asyncCreate, fetch
-import json, asyncio, datetime, aiohttp, requests
\ No newline at end of file
+import json, datetime, aiohttp, requests
\ No newline at end of file
