@@ -39,12 +39,17 @@ class Webhook():
             self.webhook["content"] = text
             self.message = text
     
-    def allowed_mentions(self, boolean):
-        """boolean if mentions are allowed from the webhook - good for making sure webhooks dont mention and vice versa - defaults true"""
-        if boolean == False:
-            self.webhook["allowed_mentions"] = "false"
-        else:
-            pass
+    def allowed_mentions(self, **kwargs):
+        """options for if mentions are allowed from the webhook: everyone, roles, users"""
+        finallist = []
+        for item in ["users", "everyone", "roles"]:
+            if item not in kwargs or kwargs[item] != False:
+                finallist.append(item)
+
+        self.webhook["allowed_mentions"] = {"parse":finallist}
+        self.allowed_mentions = finallist
+
+        return self.allowed_mentions
     
     async def send(self, WebhookURL, **kwargs):
         """send the webhook asynchronously: embed"""
